==> hadoop-hdfs-2.7.2-test-sources.jar: org/apache/hadoop/cli/CLITestCmdDFS.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.cli;

import org.apache.hadoop.cli.util.CLICommandDFSAdmin;
import org.apache.hadoop.cli.util.CLICommandTypes;
import org.apache.hadoop.cli.util.CLITestCmd;
import org.apache.hadoop.cli.util.CommandExecutor;
import org.apache.hadoop.cli.util.FSCmdExecutor;
import org.apache.hadoop.hdfs.tools.DFSAdmin;

public class CLITestCmdDFS extends CLITestCmd {
  public CLITestCmdDFS(String str, CLICommandTypes type) {
    super(str, type);
  }

  @Override
  public CommandExecutor getExecutor(String tag) throws IllegalArgumentException {
    if (getType() instanceof CLICommandDFSAdmin)
      return new FSCmdExecutor(tag, new DFSAdmin());
    return super.getExecutor(tag);
  }
}

==> hadoop-hdfs-3.2.0.15-20241003.172905-28-test-sources.jar: org/apache/hadoop/cli/CLITestCmdDFS.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.cli;

import org.apache.hadoop.cli.util.CLICommandDFSAdmin;
import org.apache.hadoop.cli.util.CLICommandTypes;
import org.apache.hadoop.cli.util.CLITestCmd;
import org.apache.hadoop.cli.util.CommandExecutor;
import org.apache.hadoop.cli.util.FSCmdExecutor;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hdfs.tools.DFSAdmin;

public class CLITestCmdDFS extends CLITestCmd {
  public CLITestCmdDFS(String str, CLICommandTypes type) {
    super(str, type);
  }

  @Override
  public CommandExecutor getExecutor(String tag, Configuration conf)
      throws IllegalArgumentException {
    if (getType() instanceof CLICommandDFSAdmin) {
      return new FSCmdExecutor(tag, new DFSAdmin());
    }
    return super.getExecutor(tag, conf);
  }
}
